/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { Client } from "./client";
import { ISegment } from "./mergeTree";
import { ICombiningOp, ReferenceType } from "./ops";
import { PropertySet } from "./properties";
import { ReferencePosition } from "./referencePositions";
/**
 * @deprecated - Use ReferencePosition
 */
export declare class LocalReference implements ReferencePosition {
    private readonly client;
    /**
     * @deprecated - use getOffset
     */
    offset: number;
    refType: ReferenceType;
    /**
     * @deprecated - use DetachedReferencePosition
     */
    static readonly DetachedPosition: number;
    properties: PropertySet | undefined;
    /**
     * @deprecated - use properties to store pair
     */
    pairedRef?: LocalReference;
    /**
     * @deprecated - use getSegment
     */
    segment: ISegment | undefined;
    /**
     * @deprecated - use createReferencePosition
     */
    constructor(client: Client, initSegment: ISegment, 
    /**
     * @deprecated - use getOffset
     */
    offset?: number, refType?: ReferenceType, properties?: PropertySet);
    /**
     * @deprecated - use minReferencePosition
     */
    min(b: LocalReference): LocalReference;
    /**
     * @deprecated - use maxReferencePosition
     */
    max(b: LocalReference): LocalReference;
    /**
     * @deprecated - use compareReferencePositions
     */
    compare(b: LocalReference): number;
    /**
     * @deprecated - use getLocalReferencePosition
     */
    toPosition(): number;
    /**
     * @deprecated - use refHasTileLabels
     */
    hasTileLabels(): boolean;
    /**
     * @deprecated - use refHasRangeLabels
     */
    hasRangeLabels(): boolean;
    /**
     * @deprecated - use refHasTileLabel
     */
    hasTileLabel(label: string): boolean;
    /**
     * @deprecated - use refHasRangeLabel
     */
    hasRangeLabel(label: string): boolean;
    /**
     * @deprecated - use refGetTileLabels
     */
    getTileLabels(): string[] | undefined;
    /**
     * @deprecated - use refGetRangeLabels
     */
    getRangeLabels(): string[] | undefined;
    isLeaf(): boolean;
    addProperties(newProps: PropertySet, op?: ICombiningOp): void;
    /**
     * @deprecated - no longer supported
     */
    getClient(): Client;
    getSegment(): ISegment | undefined;
    getOffset(): number;
    getProperties(): PropertySet | undefined;
}
interface IRefsAtOffset {
    before?: LocalReference[];
    at?: LocalReference[];
    after?: LocalReference[];
}
/**
 * Represents a collection of {@link LocalReference}s associated with one segment in a merge-tree.
 */
export declare class LocalReferenceCollection {
    /** Segment this `LocalReferenceCollection` is associated to. */
    private readonly segment;
    static append(seg1: ISegment, seg2: ISegment): void;
    hierRefCount: number;
    private readonly refsByOffset;
    private refCount;
    constructor(
    /** Segment this `LocalReferenceCollection` is associated to. */
    segment: ISegment, initialRefsByfOffset?: (IRefsAtOffset | undefined)[]);
    [Symbol.iterator](): {
        next(): IteratorResult<LocalReference>;
        [Symbol.iterator](): any;
    };
    clear(): void;
    get empty(): boolean;
    addLocalRef(lref: LocalReference): void;
    removeLocalRef(lref: LocalReference): LocalReference | undefined;
    /**
     * Called by 'append()' implementations to append local refs from the given 'other' segment to the
     * end of 'this' segment.
     *
     * Note: This method should be invoked after the caller has ensured that segments can be merged,
     *       but before 'this' segment's cachedLength has changed, or the adjustment to the local refs
     *       will be incorrect.
     */
    append(other: LocalReferenceCollection): void;
    /**
     * Splits this `LocalReferenceCollection` into the intervals [0, offset) and [offset, originalLength).
     * Local references in the former half of this split will remain associated with the segment used on construction.
     * Local references in the latter half of this split will be transferred to `splitSeg`,
     * and its `localRefs` field will be set.
     * @param offset - Offset into the original segment at which the collection should be split
     * @param splitSeg - Split segment which originally corresponded to the indices [offset, originalLength)
     * before splitting.
     */
    split(offset: number, splitSeg: ISegment): void;
    addBeforeTombstones(...refs: Iterable<LocalReference>[]): void;
    addAfterTombstones(...refs: Iterable<LocalReference>[]): void;
}
export {};
//# sourceMappingURL=localReference.d.ts.map